@@ -1,5 +1,7 @@
-/* Copyright Abandoned 1996, 1999, 2001 MySQL AB
-   This file is public domain and comes with NO WARRANTY of any kind */
+/* Copyright Abandoned 1996,1999 TCX DataKonsult AB & Monty Program KB
+   & Detron HB, 1996, 1999-2004, 2007 MySQL AB.
+   This file is public domain and comes with NO WARRANTY of any kind
+*/
 
 /* Version numbers for protocol & mysqld */
 
@@ -9,16 +11,17 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MYSQL_SERVER_VERSION		"5.1.65"
-#define MYSQL_BASE_VERSION		"mysqld-5.1"
+#define MYSQL_SERVER_VERSION		"5.5.63-MariaDB"
+#define MYSQL_BASE_VERSION		"mysqld-5.5"
+#define MARIADB_BASE_VERSION		"mariadb-5.5"
 #define MYSQL_SERVER_SUFFIX_DEF		""
 #define FRM_VER				6
-#define MYSQL_VERSION_ID		50165
+#define MYSQL_VERSION_ID		50563
 #define MYSQL_PORT			3306
 #define MYSQL_PORT_DEFAULT		0
 #define MYSQL_UNIX_ADDR			"/var/lib/mysql/mysql.sock"
 #define MYSQL_CONFIG_NAME		"my"
-#define MYSQL_COMPILATION_COMMENT	"MySQL Community Server (GPL)"
+#define MYSQL_COMPILATION_COMMENT	"MariaDB Server"
 
 /* mysqld compile time options */
 #endif /* _CUSTOMCONFIG_ */
